@@ -4,7 +4,7 @@ import traceback
 from asyncio import StreamReader, FIRST_EXCEPTION
 from datetime import datetime, timezone, timedelta
 from subprocess import PIPE, STDOUT, Popen
-from typing import List, Tuple, Optional, Dict, TypeAlias, Callable
+from typing import List, Tuple, Optional, Dict, TypeAlias, Callable, Any
 
 from dateutil.parser import parse as dateutil_parse
 
@@ -205,3 +205,26 @@ def is_single_none(*args) -> bool:
     for arg in args:
         res += int(arg is None)
     return res == 1
+
+
+def any_to_opt_bool(value: Any, default: Optional[bool] = None) -> Optional[bool]:
+    if value is None:
+        return default
+    if value == 1:
+        return True
+    if value == 0:
+        return False
+    if str(value).lower() in ["true", "t", "1", "yes"]:
+        return True
+    if str(value).lower() in ["false", "f", "0", "no"]:
+        return False
+    return default
+
+
+def any_to_bool(value: Any, default: Optional[bool] = None) -> bool:
+    res = any_to_opt_bool(value, default)
+    if res is not None:
+        return res
+    if default is None:
+        raise ValueError('Could not convert "{}" to boolean value'.format(value))
+    return default
